summaryrefslogtreecommitdiff
path: root/gcc/choose-temp.c
diff options
context:
space:
mode:
authorDoug Evans <dje@gnu.org>1996-04-17 18:41:12 +0000
committerDoug Evans <dje@gnu.org>1996-04-17 18:41:12 +0000
commit0980566f5d49ff1fffd0fc2a211bda8783a90fb0 (patch)
tree88274f9b117ed5ecc6669bfb644523f4d7548a80 /gcc/choose-temp.c
parent6524f6537cc038c96af638a6e5a319f18d583023 (diff)
downloadgcc-0980566f5d49ff1fffd0fc2a211bda8783a90fb0.tar.gz
(choose_tmpdir): Renamed from choose_temp_base.
#include <stdio.h>. From-SVN: r11836
Diffstat (limited to 'gcc/choose-temp.c')
-rw-r--r--gcc/choose-temp.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/gcc/choose-temp.c b/gcc/choose-temp.c
index 009147fbc41..73a741167b0 100644
--- a/gcc/choose-temp.c
+++ b/gcc/choose-temp.c
@@ -17,7 +17,7 @@ License along with libiberty; see the file COPYING.LIB. If
not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
/* This file exports one function: choose_temp_base. */
#if ! defined (_WIN32) && ! defined (NO_SYS_FILE_H)
#include <sys/file.h> /* May get R_OK, etc. on some systems. */
@@ -29,6 +29,8 @@ Boston, MA 02111-1307, USA. */
#define X_OK 1
#endif
+#include <stdio.h> /* May get P_tmpdir. */
+
#ifdef IN_GCC
#include "config.h"
#include "gansidecl.h"
@@ -85,7 +87,7 @@ try (dir, base)
The buffer for the result is obtained with xmalloc. */
char *
-choose_temp_base ()
+choose_tmpdir ()
{
char *base = 0;
char *temp_filename;
@@ -17,7 +17,7 @@ License along with libiberty; see the file COPYING.LIB. If
not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
-/* This file exports one function: choose_temp_base. */
+/* This file exports one function: choose_tmpdir. */
#if ! defined (_WIN32) && ! defined (NO_SYS_FILE_H)
#include <sys/file.h> /* May get R_OK, etc. on some systems. */